package com.javacodegeeks.presencebt;

import android.app.Activity;
import android.app.ProgressDialog;
import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.bluetooth.BluetoothSocket;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.AsyncTask;
import android.os.Bundle;
import android.os.Handler;
import android.support.v7.app.ActionBarActivity;
import android.view.View;
import android.widget.TextView;
import android.widget.EditText;
import android.widget.Button;
import android.widget.Toast;

import org.apache.http.HttpResponse;
import org.apache.http.NameValuePair;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.HttpClient;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.message.BasicNameValuePair;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.Set;
import java.util.UUID;

public class ConnectActivity extends ActionBarActivity {
    BluetoothAdapter mBluetoothAdapter;
    Button openButton;
    Button sendButton;
    BluetoothDevice mmDevice;
    String user_email;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_connect);
        openButton = (Button)findViewById(R.id.open);
        sendButton = (Button)findViewById(R.id.send);
        sendButton.setVisibility(View.GONE);

        Bundle extras = getIntent().getExtras();
        if (extras != null) {
            user_email = extras.getString("user_email");
        }

        mBluetoothAdapter = BluetoothAdapter.getDefaultAdapter();
        if(mBluetoothAdapter == null) {
            Toast.makeText(ConnectActivity.this,"No bluetooth adapter available",Toast.LENGTH_SHORT);
        }

        if(!mBluetoothAdapter.isEnabled()) {
            Intent enableBluetooth = new Intent(BluetoothAdapter.ACTION_REQUEST_ENABLE);
            startActivityForResult(enableBluetooth, 0);
        }

        openButton.setOnClickListener(new View.OnClickListener() {
            public void onClick(View v) {

                Set<BluetoothDevice> pairedDevices = mBluetoothAdapter.getBondedDevices();
                if (pairedDevices.size() > 0) {
                    for (BluetoothDevice device : pairedDevices) {
                        if (device.getName().equals("ARD_SPP")) {
                            sendButton.setVisibility(View.VISIBLE);
                            Toast.makeText(ConnectActivity.this, "Arduino server found, please sign up 1111", Toast.LENGTH_SHORT);
                            break;
                        }
                    }
                }
                IntentFilter filter = new IntentFilter();
                filter.addAction(BluetoothDevice.ACTION_FOUND);
                filter.addAction(BluetoothAdapter.ACTION_DISCOVERY_STARTED);
                filter.addAction(BluetoothAdapter.ACTION_DISCOVERY_FINISHED);
                registerReceiver(discoveryResult, filter);
                mBluetoothAdapter.startDiscovery();

                }
            });


        sendButton.setOnClickListener(new View.OnClickListener() {
            public void onClick(View v) {
                InsertData insert = new InsertData();
                insert.execute("http://45.63.104.97/arduinoCheckInApp.php");
            }
        });

    }

    private final BroadcastReceiver discoveryResult = new BroadcastReceiver() {
        private boolean b = false;
        private ProgressDialog dialog;
        @Override
        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            if (BluetoothAdapter.ACTION_DISCOVERY_STARTED.equals(action)){
                dialog = new ProgressDialog(ConnectActivity.this);
                dialog.setMessage("Searching for Arduino server...");
                dialog.show();
            }
            else if (BluetoothAdapter.ACTION_DISCOVERY_FINISHED.equals(action)){
                dialog.dismiss();
                if (!b)
                    Toast.makeText(ConnectActivity.this, "Server not found", Toast.LENGTH_SHORT).show();
            }
            else if (BluetoothDevice.ACTION_FOUND.equals(action)){
                String deviceName = intent.getStringExtra(BluetoothDevice.EXTRA_NAME);
                if (deviceName.equals("ARD_SPP")) {
                    Toast.makeText(ConnectActivity.this, "Arduino server found, please sign up 2222", Toast.LENGTH_SHORT).show();
                    sendButton.setVisibility(View.VISIBLE);
                    openButton.setVisibility(View.GONE);
                    b = true;
                    dialog.dismiss();
                }
            }
        }
    };

    private class InsertData extends AsyncTask<String, Void, Boolean> {
        ProgressDialog dialog = new ProgressDialog(ConnectActivity.this);

        @Override
        protected void onPreExecute() {
            super.onPreExecute();
            dialog.setMessage("Signing up...");
            dialog.show();
        }

        @Override
        protected Boolean doInBackground(String... params) {
            for(String url1 : params){

                try {
                    ArrayList<NameValuePair> pairs = new ArrayList<>();
                    pairs.add(new BasicNameValuePair("user_email",user_email ));
                    pairs.add(new BasicNameValuePair("server_name", "ARD_SPP"));
                    HttpClient client = new DefaultHttpClient();
                    HttpPost post = new HttpPost(url1);
                    post.setEntity(new UrlEncodedFormEntity(pairs));
                    HttpResponse response = client.execute(post);
                }   catch (ClientProtocolException e) {
                    e.printStackTrace();
                    return false;
                }
                catch (IOException e) {
                    e.printStackTrace();
                    return  false;
                }
            }
            return true;
        }

        @Override
        protected void onPostExecute(Boolean aBoolean) {
            super.onPostExecute(aBoolean);
            if(aBoolean == true){
                Toast.makeText(ConnectActivity.this,"You are successfully signed up",Toast.LENGTH_LONG).show();
            }
            else {
                Toast.makeText(ConnectActivity.this,"Error",Toast.LENGTH_LONG).show();
            }
            dialog.dismiss();
        }
    }
}
